@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::GenPericmdScript;
 
 our $DATE = '2017-01-06'; # DATE
-our $VERSION = '0.35'; # VERSION
+our $VERSION = '0.36'; # VERSION
 
 use 5.010001;
 use strict;
@@ -109,7 +109,7 @@ sub munge_files {
 
     my $subcommands;
     if ($self->subcommands) {
-        $subcommands = [split /\s*,\s*/, $self->subcommands];
+        $subcommands = {split /\s*=\s*|\s+/, $self->subcommands};
     }
 
     my $res;
@@ -190,10 +190,9 @@ sub munge_files {
         }
 
         my @urls = ($self->url);
-        if ($subcommands && @$subcommands) {
-            for my $sc (@$subcommands) {
-                /:(.+)/;
-                push @urls, $1;
+        if ($subcommands && keys %$subcommands) {
+            for my $sc_name (sort keys %$subcommands) {
+                push @urls, $subcommands->{$sc_name};
             }
         }
         # add prereq to script backend modules
@@ -254,7 +253,7 @@ Dist::Zilla::Plugin::GenPericmdScript - Generate Perinci::CmdLine script
 
 =head1 VERSION
 
-This document describes version 0.35 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2017-01-06.
+This document describes version 0.36 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2017-01-06.
 
 =head1 SYNOPSIS
 
@@ -326,11 +325,11 @@ package URL.
 
 =head2 subcommands => str
 
-For creating a CLI script with subcommands. Value is a comma-separated entries
-of subcommand specification. Each subcommand specification must be in the form
-of SUBCOMMAND_NAME:URL[:SUMMARY]. Example:
+For creating a CLI script with subcommands. Value is a whitespace-separated
+entries of subcommand specification. Each subcommand specification must be in
+the form of SUBCOMMAND_NAME=URL[:SUMMARY]. Example:
 
- delete:/My/App/delete_item, add:/My/App/add_item, refresh:/My/App/refresh_item:Refetch an item from source
+ delete=/My/App/delete_item add=/My/App/add_item refresh=/My/App/refresh_item:Refetch an item from source
 
 =head2 subcommands_from_package_functions => bool
 
